@@ -1,5 +1,5 @@
 
-onesampb <- function(x, est = "onestep", nboot = 2000, nv = 0){
+onesampb <- function(x, est = "onestep", nboot = 2000, nv = 0, alpha = 0.05){
   #
   #   Compute a bootstrap, .95 confidence interval for the
   #   measure of location corresponding to the argument est.
@@ -13,7 +13,7 @@ onesampb <- function(x, est = "onestep", nboot = 2000, nv = 0){
   est <- match.arg(est, c("mom", "onestep", "median"), several.ok = FALSE)
   est <- get(est)
   
-  alpha <- 0.05
+  
   null.value <- NULL
   if(!is.null(null.value))nv=null.value
   #if(SEED)set.seed(2) # set seed of random number generator so that
@@ -29,7 +29,7 @@ onesampb <- function(x, est = "onestep", nboot = 2000, nv = 0){
   pv=mean(bvec>nv)+.5*mean(bvec==nv)
   pv=2*min(c(pv,1-pv))
   estimate=est(x)
-  result <- list(ci=c(bvec[low],bvec[up]), n=length(x), estimate=estimate, p.value=pv, call=cl)
+  result <- list(ci=c(bvec[low],bvec[up]), n=length(x), estimate=estimate, p.value=pv, alpha = alpha,call=cl)
   class(result) <- "onesampb"
   return(result)
 }
\ No newline at end of file
